@@ -61,7 +61,7 @@
 #define KPIPEWIRE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPIPEWIRE_NO_DEPRECATED
-#  define KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51b06
+#  define KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51b0a
 #endif
 #ifdef KPIPEWIRE_NO_DEPRECATED_WARNINGS
 #  define KPIPEWIRE_DEPRECATED_WARNINGS_SINCE 0
@@ -71,7 +71,7 @@
 #  ifdef KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPIPEWIRE_DEPRECATED_WARNINGS_SINCE KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPIPEWIRE_DEPRECATED_WARNINGS_SINCE 0x51b06
+#    define KPIPEWIRE_DEPRECATED_WARNINGS_SINCE 0x51b0a
 #  endif
 #endif
 
